"""
    Network API reference

       # noqa: E501

    The version of the OpenAPI document: 1.0.0
    Generated by: https://openapi-generator.tech
"""


import sys
import unittest

import psm
from pensando_dss.psm.model.network_ipam_config import NetworkIPAMConfig
from pensando_dss.psm.model.network_orchestrator_info import NetworkOrchestratorInfo
from pensando_dss.psm.model.network_rd_spec import NetworkRDSpec
globals()['NetworkIPAMConfig'] = NetworkIPAMConfig
globals()['NetworkOrchestratorInfo'] = NetworkOrchestratorInfo
globals()['NetworkRDSpec'] = NetworkRDSpec
from pensando_dss.psm.psm.model.network_network_spec import NetworkNetworkSpec


class TestNetworkNetworkSpec(unittest.TestCase):
    """NetworkNetworkSpec unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def testNetworkNetworkSpec(self):
        """Test NetworkNetworkSpec"""
        # FIXME: construct object with mandatory attributes with example values
        # model = NetworkNetworkSpec()  # noqa: E501
        pass


if __name__ == '__main__':
    unittest.main()
