"""
    Sysruntime API reference

    Service name    # noqa: E501

    The version of the OpenAPI document: 1.0.0
    Generated by: https://openapi-generator.tech
"""


import unittest

import psm
from pensando_dss.psm.api.distributedservicecards_v1_api import DistributedservicecardsV1Api  # noqa: E501


class TestDistributedservicecardsV1Api(unittest.TestCase):
    """DistributedservicecardsV1Api unit test stubs"""

    def setUp(self):
        self.api = DistributedservicecardsV1Api()  # noqa: E501

    def tearDown(self):
        pass

    def test_post_query_connection(self):
        """Test case for post_query_connection

        Active Connection Query  # noqa: E501
        """
        pass


if __name__ == '__main__':
    unittest.main()
