"""
    Staging API reference

    Service name    # noqa: E501

    The version of the OpenAPI document: 1.0.0
    Generated by: https://openapi-generator.tech
"""


import sys
import unittest

import psm
from pensando_dss.psm.model.bulkedit_bulk_edit_item import BulkeditBulkEditItem
globals()['BulkeditBulkEditItem'] = BulkeditBulkEditItem
from pensando_dss.psm.psm.model.bulkedit_bulk_edit_action_spec import BulkeditBulkEditActionSpec


class TestBulkeditBulkEditActionSpec(unittest.TestCase):
    """BulkeditBulkEditActionSpec unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def testBulkeditBulkEditActionSpec(self):
        """Test BulkeditBulkEditActionSpec"""
        # FIXME: construct object with mandatory attributes with example values
        # model = BulkeditBulkEditActionSpec()  # noqa: E501
        pass


if __name__ == '__main__':
    unittest.main()
