"""
    Recoverykeys API reference

    Service name    # noqa: E501

    The version of the OpenAPI document: 1.0.0
    Generated by: https://openapi-generator.tech
"""


import unittest

import psm
from pensando_dss.psm.api.recoverykeys_v1_api import RecoverykeysV1Api  # noqa: E501


class TestRecoverykeysV1Api(unittest.TestCase):
    """RecoverykeysV1Api unit test stubs"""

    def setUp(self):
        self.api = RecoverykeysV1Api()  # noqa: E501

    def tearDown(self):
        pass

    def test_get_download_recovery_keys(self):
        """Test case for get_download_recovery_keys

        """
        pass


if __name__ == '__main__':
    unittest.main()
