"""
    Security API reference

       # noqa: E501

    The version of the OpenAPI document: 1.0.0
    Generated by: https://openapi-generator.tech
"""


import sys
import unittest

import psm
from pensando_dss.psm.model.api_object_meta import ApiObjectMeta
from pensando_dss.psm.model.security_network_security_policy_spec import SecurityNetworkSecurityPolicySpec
from pensando_dss.psm.model.security_network_security_policy_status import SecurityNetworkSecurityPolicyStatus
globals()['ApiObjectMeta'] = ApiObjectMeta
globals()['SecurityNetworkSecurityPolicySpec'] = SecurityNetworkSecurityPolicySpec
globals()['SecurityNetworkSecurityPolicyStatus'] = SecurityNetworkSecurityPolicyStatus
from pensando_dss.psm.psm.model.security_network_security_policy import SecurityNetworkSecurityPolicy


class TestSecurityNetworkSecurityPolicy(unittest.TestCase):
    """SecurityNetworkSecurityPolicy unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def testSecurityNetworkSecurityPolicy(self):
        """Test SecurityNetworkSecurityPolicy"""
        # FIXME: construct object with mandatory attributes with example values
        # model = SecurityNetworkSecurityPolicy()  # noqa: E501
        pass


if __name__ == '__main__':
    unittest.main()
