"""
    Preferences API reference

    Service name    # noqa: E501

    The version of the OpenAPI document: 1.0.0
    Generated by: https://openapi-generator.tech
"""


import sys
import unittest

import psm
from pensando_dss.psm.model.preferences_ui_global_settings import PreferencesUIGlobalSettings
globals()['PreferencesUIGlobalSettings'] = PreferencesUIGlobalSettings
from pensando_dss.psm.psm.model.preferences_auto_msg_ui_global_settings_watch_helper_watch_event import PreferencesAutoMsgUIGlobalSettingsWatchHelperWatchEvent


class TestPreferencesAutoMsgUIGlobalSettingsWatchHelperWatchEvent(unittest.TestCase):
    """PreferencesAutoMsgUIGlobalSettingsWatchHelperWatchEvent unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def testPreferencesAutoMsgUIGlobalSettingsWatchHelperWatchEvent(self):
        """Test PreferencesAutoMsgUIGlobalSettingsWatchHelperWatchEvent"""
        # FIXME: construct object with mandatory attributes with example values
        # model = PreferencesAutoMsgUIGlobalSettingsWatchHelperWatchEvent()  # noqa: E501
        pass


if __name__ == '__main__':
    unittest.main()
