"""
    Security API reference

       # noqa: E501

    The version of the OpenAPI document: 1.0.0
    Generated by: https://openapi-generator.tech
"""


import sys
import unittest

import psm
from pensando_dss.psm.model.api_object_meta import ApiObjectMeta
from pensando_dss.psm.model.security_certificate_spec import SecurityCertificateSpec
from pensando_dss.psm.model.security_certificate_status import SecurityCertificateStatus
globals()['ApiObjectMeta'] = ApiObjectMeta
globals()['SecurityCertificateSpec'] = SecurityCertificateSpec
globals()['SecurityCertificateStatus'] = SecurityCertificateStatus
from pensando_dss.psm.psm.model.security_certificate import SecurityCertificate


class TestSecurityCertificate(unittest.TestCase):
    """SecurityCertificate unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def testSecurityCertificate(self):
        """Test SecurityCertificate"""
        # FIXME: construct object with mandatory attributes with example values
        # model = SecurityCertificate()  # noqa: E501
        pass


if __name__ == '__main__':
    unittest.main()
