"""
    Aggwatch API reference

       # noqa: E501

    The version of the OpenAPI document: v1
    Generated by: https://openapi-generator.tech
"""


import sys
import unittest

import psm
from pensando_dss.psm.psm.model.api_watch_control import ApiWatchControl


class TestApiWatchControl(unittest.TestCase):
    """ApiWatchControl unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def testApiWatchControl(self):
        """Test ApiWatchControl"""
        # FIXME: construct object with mandatory attributes with example values
        # model = ApiWatchControl()  # noqa: E501
        pass


if __name__ == '__main__':
    unittest.main()
