"""
    Sysruntime API reference

    Service name    # noqa: E501

    The version of the OpenAPI document: 1.0.0
    Generated by: https://openapi-generator.tech
"""


import sys
import unittest

import psm
from pensando_dss.psm.model.sysruntime_flow_data import SysruntimeFlowData
from pensando_dss.psm.model.sysruntime_flow_key import SysruntimeFlowKey
globals()['SysruntimeFlowData'] = SysruntimeFlowData
globals()['SysruntimeFlowKey'] = SysruntimeFlowKey
from pensando_dss.psm.psm.model.sysruntime_flow_spec import SysruntimeFlowSpec


class TestSysruntimeFlowSpec(unittest.TestCase):
    """SysruntimeFlowSpec unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def testSysruntimeFlowSpec(self):
        """Test SysruntimeFlowSpec"""
        # FIXME: construct object with mandatory attributes with example values
        # model = SysruntimeFlowSpec()  # noqa: E501
        pass


if __name__ == '__main__':
    unittest.main()
