"""
    Rollout API reference

    Service name    # noqa: E501

    The version of the OpenAPI document: 1.0.0
    Generated by: https://openapi-generator.tech
"""


import sys
import unittest

import psm
from pensando_dss.psm.model.rollout_auto_msg_rollout_action_watch_helper_watch_event import RolloutAutoMsgRolloutActionWatchHelperWatchEvent
globals()['RolloutAutoMsgRolloutActionWatchHelperWatchEvent'] = RolloutAutoMsgRolloutActionWatchHelperWatchEvent
from pensando_dss.psm.psm.model.rollout_auto_msg_rollout_action_watch_helper import RolloutAutoMsgRolloutActionWatchHelper


class TestRolloutAutoMsgRolloutActionWatchHelper(unittest.TestCase):
    """RolloutAutoMsgRolloutActionWatchHelper unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def testRolloutAutoMsgRolloutActionWatchHelper(self):
        """Test RolloutAutoMsgRolloutActionWatchHelper"""
        # FIXME: construct object with mandatory attributes with example values
        # model = RolloutAutoMsgRolloutActionWatchHelper()  # noqa: E501
        pass


if __name__ == '__main__':
    unittest.main()
