"""
    Security API reference

       # noqa: E501

    The version of the OpenAPI document: 1.0.0
    Generated by: https://openapi-generator.tech
"""


import sys
import unittest

import psm
from pensando_dss.psm.model.api_list_meta import ApiListMeta
from pensando_dss.psm.model.security_network_security_policy import SecurityNetworkSecurityPolicy
globals()['ApiListMeta'] = ApiListMeta
globals()['SecurityNetworkSecurityPolicy'] = SecurityNetworkSecurityPolicy
from pensando_dss.psm.psm.model.security_network_security_policy_list import SecurityNetworkSecurityPolicyList


class TestSecurityNetworkSecurityPolicyList(unittest.TestCase):
    """SecurityNetworkSecurityPolicyList unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def testSecurityNetworkSecurityPolicyList(self):
        """Test SecurityNetworkSecurityPolicyList"""
        # FIXME: construct object with mandatory attributes with example values
        # model = SecurityNetworkSecurityPolicyList()  # noqa: E501
        pass


if __name__ == '__main__':
    unittest.main()
