"""
    Telemetry_query API reference

    Service name    # noqa: E501

    The version of the OpenAPI document: v1
    Generated by: https://openapi-generator.tech
"""


import sys
import unittest

import psm
from pensando_dss.psm.model.telemetry_query_result_series import TelemetryQueryResultSeries
globals()['TelemetryQueryResultSeries'] = TelemetryQueryResultSeries
from pensando_dss.psm.psm.model.telemetry_query_metrics_query_result import TelemetryQueryMetricsQueryResult


class TestTelemetryQueryMetricsQueryResult(unittest.TestCase):
    """TelemetryQueryMetricsQueryResult unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def testTelemetryQueryMetricsQueryResult(self):
        """Test TelemetryQueryMetricsQueryResult"""
        # FIXME: construct object with mandatory attributes with example values
        # model = TelemetryQueryMetricsQueryResult()  # noqa: E501
        pass


if __name__ == '__main__':
    unittest.main()
