"""
    Network API reference

       # noqa: E501

    The version of the OpenAPI document: 1.0.0
    Generated by: https://openapi-generator.tech
"""


import sys
import unittest

import psm
from pensando_dss.psm.model.api_list_meta import ApiListMeta
from pensando_dss.psm.model.network_ipam_policy import NetworkIPAMPolicy
globals()['ApiListMeta'] = ApiListMeta
globals()['NetworkIPAMPolicy'] = NetworkIPAMPolicy
from pensando_dss.psm.psm.model.network_ipam_policy_list import NetworkIPAMPolicyList


class TestNetworkIPAMPolicyList(unittest.TestCase):
    """NetworkIPAMPolicyList unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def testNetworkIPAMPolicyList(self):
        """Test NetworkIPAMPolicyList"""
        # FIXME: construct object with mandatory attributes with example values
        # model = NetworkIPAMPolicyList()  # noqa: E501
        pass


if __name__ == '__main__':
    unittest.main()
