"""
    Monitoring API reference

    Service name    # noqa: E501

    The version of the OpenAPI document: 1.0.0
    Generated by: https://openapi-generator.tech
"""


import unittest

import psm
from pensando_dss.psm.api.monitoring_v1_api import MonitoringV1Api  # noqa: E501


class TestMonitoringV1Api(unittest.TestCase):
    """MonitoringV1Api unit test stubs"""

    def setUp(self):
        self.api = MonitoringV1Api()  # noqa: E501

    def tearDown(self):
        pass

    def test_add_alert_destination(self):
        """Test case for add_alert_destination

        Create AlertDestination object  # noqa: E501
        """
        pass

    def test_add_alert_destination1(self):
        """Test case for add_alert_destination1

        Create AlertDestination object  # noqa: E501
        """
        pass

    def test_add_alert_policy(self):
        """Test case for add_alert_policy

        Create AlertPolicy object  # noqa: E501
        """
        pass

    def test_add_alert_policy1(self):
        """Test case for add_alert_policy1

        Create AlertPolicy object  # noqa: E501
        """
        pass

    def test_add_archive_request(self):
        """Test case for add_archive_request

        Create ArchiveRequest object  # noqa: E501
        """
        pass

    def test_add_archive_request1(self):
        """Test case for add_archive_request1

        Create ArchiveRequest object  # noqa: E501
        """
        pass

    def test_add_audit_policy(self):
        """Test case for add_audit_policy

        Create AuditPolicy object  # noqa: E501
        """
        pass

    def test_add_audit_policy1(self):
        """Test case for add_audit_policy1

        Create AuditPolicy object  # noqa: E501
        """
        pass

    def test_add_event_policy(self):
        """Test case for add_event_policy

        Create EventPolicy object  # noqa: E501
        """
        pass

    def test_add_event_policy1(self):
        """Test case for add_event_policy1

        Create EventPolicy object  # noqa: E501
        """
        pass

    def test_add_flow_export_policy(self):
        """Test case for add_flow_export_policy

        Create FlowExportPolicy object  # noqa: E501
        """
        pass

    def test_add_flow_export_policy1(self):
        """Test case for add_flow_export_policy1

        Create FlowExportPolicy object  # noqa: E501
        """
        pass

    def test_add_fwlog_policy(self):
        """Test case for add_fwlog_policy

        Create FwlogPolicy object  # noqa: E501
        """
        pass

    def test_add_fwlog_policy1(self):
        """Test case for add_fwlog_policy1

        Create FwlogPolicy object  # noqa: E501
        """
        pass

    def test_add_mirror_session(self):
        """Test case for add_mirror_session

        Create MirrorSession object  # noqa: E501
        """
        pass

    def test_add_mirror_session1(self):
        """Test case for add_mirror_session1

        Create MirrorSession object  # noqa: E501
        """
        pass

    def test_add_stats_alert_policy(self):
        """Test case for add_stats_alert_policy

        Create StatsAlertPolicy object  # noqa: E501
        """
        pass

    def test_add_stats_alert_policy1(self):
        """Test case for add_stats_alert_policy1

        Create StatsAlertPolicy object  # noqa: E501
        """
        pass

    def test_add_tech_support_request(self):
        """Test case for add_tech_support_request

        Create TechSupportRequest object  # noqa: E501
        """
        pass

    def test_add_troubleshooting_session(self):
        """Test case for add_troubleshooting_session

        Create TroubleshootingSession object  # noqa: E501
        """
        pass

    def test_add_troubleshooting_session1(self):
        """Test case for add_troubleshooting_session1

        Create TroubleshootingSession object  # noqa: E501
        """
        pass

    def test_cancel(self):
        """Test case for cancel

        """
        pass

    def test_cancel1(self):
        """Test case for cancel1

        """
        pass

    def test_delete_alert_destination(self):
        """Test case for delete_alert_destination

        Delete AlertDestination object  # noqa: E501
        """
        pass

    def test_delete_alert_destination1(self):
        """Test case for delete_alert_destination1

        Delete AlertDestination object  # noqa: E501
        """
        pass

    def test_delete_alert_policy(self):
        """Test case for delete_alert_policy

        Delete AlertPolicy object  # noqa: E501
        """
        pass

    def test_delete_alert_policy1(self):
        """Test case for delete_alert_policy1

        Delete AlertPolicy object  # noqa: E501
        """
        pass

    def test_delete_archive_request(self):
        """Test case for delete_archive_request

        Delete ArchiveRequest object  # noqa: E501
        """
        pass

    def test_delete_archive_request1(self):
        """Test case for delete_archive_request1

        Delete ArchiveRequest object  # noqa: E501
        """
        pass

    def test_delete_audit_policy(self):
        """Test case for delete_audit_policy

        Delete AuditPolicy object  # noqa: E501
        """
        pass

    def test_delete_audit_policy1(self):
        """Test case for delete_audit_policy1

        Delete AuditPolicy object  # noqa: E501
        """
        pass

    def test_delete_event_policy(self):
        """Test case for delete_event_policy

        Delete EventPolicy object  # noqa: E501
        """
        pass

    def test_delete_event_policy1(self):
        """Test case for delete_event_policy1

        Delete EventPolicy object  # noqa: E501
        """
        pass

    def test_delete_flow_export_policy(self):
        """Test case for delete_flow_export_policy

        Delete FlowExportPolicy object  # noqa: E501
        """
        pass

    def test_delete_flow_export_policy1(self):
        """Test case for delete_flow_export_policy1

        Delete FlowExportPolicy object  # noqa: E501
        """
        pass

    def test_delete_fwlog_policy(self):
        """Test case for delete_fwlog_policy

        Delete FwlogPolicy object  # noqa: E501
        """
        pass

    def test_delete_fwlog_policy1(self):
        """Test case for delete_fwlog_policy1

        Delete FwlogPolicy object  # noqa: E501
        """
        pass

    def test_delete_mirror_session(self):
        """Test case for delete_mirror_session

        Delete MirrorSession object  # noqa: E501
        """
        pass

    def test_delete_mirror_session1(self):
        """Test case for delete_mirror_session1

        Delete MirrorSession object  # noqa: E501
        """
        pass

    def test_delete_stats_alert_policy(self):
        """Test case for delete_stats_alert_policy

        Delete StatsAlertPolicy object  # noqa: E501
        """
        pass

    def test_delete_stats_alert_policy1(self):
        """Test case for delete_stats_alert_policy1

        Delete StatsAlertPolicy object  # noqa: E501
        """
        pass

    def test_delete_tech_support_request(self):
        """Test case for delete_tech_support_request

        Delete TechSupportRequest object  # noqa: E501
        """
        pass

    def test_delete_troubleshooting_session(self):
        """Test case for delete_troubleshooting_session

        Delete TroubleshootingSession object  # noqa: E501
        """
        pass

    def test_delete_troubleshooting_session1(self):
        """Test case for delete_troubleshooting_session1

        Delete TroubleshootingSession object  # noqa: E501
        """
        pass

    def test_get_alert(self):
        """Test case for get_alert

        Get Alert object  # noqa: E501
        """
        pass

    def test_get_alert1(self):
        """Test case for get_alert1

        Get Alert object  # noqa: E501
        """
        pass

    def test_get_alert_destination(self):
        """Test case for get_alert_destination

        Get AlertDestination object  # noqa: E501
        """
        pass

    def test_get_alert_destination1(self):
        """Test case for get_alert_destination1

        Get AlertDestination object  # noqa: E501
        """
        pass

    def test_get_alert_policy(self):
        """Test case for get_alert_policy

        Get AlertPolicy object  # noqa: E501
        """
        pass

    def test_get_alert_policy1(self):
        """Test case for get_alert_policy1

        Get AlertPolicy object  # noqa: E501
        """
        pass

    def test_get_archive_request(self):
        """Test case for get_archive_request

        Get ArchiveRequest object  # noqa: E501
        """
        pass

    def test_get_archive_request1(self):
        """Test case for get_archive_request1

        Get ArchiveRequest object  # noqa: E501
        """
        pass

    def test_get_audit_policy(self):
        """Test case for get_audit_policy

        Get AuditPolicy object  # noqa: E501
        """
        pass

    def test_get_audit_policy1(self):
        """Test case for get_audit_policy1

        Get AuditPolicy object  # noqa: E501
        """
        pass

    def test_get_event_policy(self):
        """Test case for get_event_policy

        Get EventPolicy object  # noqa: E501
        """
        pass

    def test_get_event_policy1(self):
        """Test case for get_event_policy1

        Get EventPolicy object  # noqa: E501
        """
        pass

    def test_get_flow_export_policy(self):
        """Test case for get_flow_export_policy

        Get FlowExportPolicy object  # noqa: E501
        """
        pass

    def test_get_flow_export_policy1(self):
        """Test case for get_flow_export_policy1

        Get FlowExportPolicy object  # noqa: E501
        """
        pass

    def test_get_fwlog_policy(self):
        """Test case for get_fwlog_policy

        Get FwlogPolicy object  # noqa: E501
        """
        pass

    def test_get_fwlog_policy1(self):
        """Test case for get_fwlog_policy1

        Get FwlogPolicy object  # noqa: E501
        """
        pass

    def test_get_mirror_session(self):
        """Test case for get_mirror_session

        Get MirrorSession object  # noqa: E501
        """
        pass

    def test_get_mirror_session1(self):
        """Test case for get_mirror_session1

        Get MirrorSession object  # noqa: E501
        """
        pass

    def test_get_stats_alert_policy(self):
        """Test case for get_stats_alert_policy

        Get StatsAlertPolicy object  # noqa: E501
        """
        pass

    def test_get_stats_alert_policy1(self):
        """Test case for get_stats_alert_policy1

        Get StatsAlertPolicy object  # noqa: E501
        """
        pass

    def test_get_tech_support_request(self):
        """Test case for get_tech_support_request

        Get TechSupportRequest object  # noqa: E501
        """
        pass

    def test_get_troubleshooting_session(self):
        """Test case for get_troubleshooting_session

        Get TroubleshootingSession object  # noqa: E501
        """
        pass

    def test_get_troubleshooting_session1(self):
        """Test case for get_troubleshooting_session1

        Get TroubleshootingSession object  # noqa: E501
        """
        pass

    def test_label_alert(self):
        """Test case for label_alert

        Label Alert object  # noqa: E501
        """
        pass

    def test_label_alert1(self):
        """Test case for label_alert1

        Label Alert object  # noqa: E501
        """
        pass

    def test_label_alert_destination(self):
        """Test case for label_alert_destination

        Label AlertDestination object  # noqa: E501
        """
        pass

    def test_label_alert_destination1(self):
        """Test case for label_alert_destination1

        Label AlertDestination object  # noqa: E501
        """
        pass

    def test_label_alert_policy(self):
        """Test case for label_alert_policy

        Label AlertPolicy object  # noqa: E501
        """
        pass

    def test_label_alert_policy1(self):
        """Test case for label_alert_policy1

        Label AlertPolicy object  # noqa: E501
        """
        pass

    def test_label_event_policy(self):
        """Test case for label_event_policy

        Label EventPolicy object  # noqa: E501
        """
        pass

    def test_label_event_policy1(self):
        """Test case for label_event_policy1

        Label EventPolicy object  # noqa: E501
        """
        pass

    def test_label_flow_export_policy(self):
        """Test case for label_flow_export_policy

        Label FlowExportPolicy object  # noqa: E501
        """
        pass

    def test_label_flow_export_policy1(self):
        """Test case for label_flow_export_policy1

        Label FlowExportPolicy object  # noqa: E501
        """
        pass

    def test_label_fwlog_policy(self):
        """Test case for label_fwlog_policy

        Label FwlogPolicy object  # noqa: E501
        """
        pass

    def test_label_fwlog_policy1(self):
        """Test case for label_fwlog_policy1

        Label FwlogPolicy object  # noqa: E501
        """
        pass

    def test_label_mirror_session(self):
        """Test case for label_mirror_session

        Label MirrorSession object  # noqa: E501
        """
        pass

    def test_label_mirror_session1(self):
        """Test case for label_mirror_session1

        Label MirrorSession object  # noqa: E501
        """
        pass

    def test_label_stats_alert_policy(self):
        """Test case for label_stats_alert_policy

        Label StatsAlertPolicy object  # noqa: E501
        """
        pass

    def test_label_stats_alert_policy1(self):
        """Test case for label_stats_alert_policy1

        Label StatsAlertPolicy object  # noqa: E501
        """
        pass

    def test_label_troubleshooting_session(self):
        """Test case for label_troubleshooting_session

        Label TroubleshootingSession object  # noqa: E501
        """
        pass

    def test_label_troubleshooting_session1(self):
        """Test case for label_troubleshooting_session1

        Label TroubleshootingSession object  # noqa: E501
        """
        pass

    def test_list_alert(self):
        """Test case for list_alert

        List Alert objects  # noqa: E501
        """
        pass

    def test_list_alert1(self):
        """Test case for list_alert1

        List Alert objects  # noqa: E501
        """
        pass

    def test_list_alert_destination(self):
        """Test case for list_alert_destination

        List AlertDestination objects  # noqa: E501
        """
        pass

    def test_list_alert_destination1(self):
        """Test case for list_alert_destination1

        List AlertDestination objects  # noqa: E501
        """
        pass

    def test_list_alert_policy(self):
        """Test case for list_alert_policy

        List AlertPolicy objects  # noqa: E501
        """
        pass

    def test_list_alert_policy1(self):
        """Test case for list_alert_policy1

        List AlertPolicy objects  # noqa: E501
        """
        pass

    def test_list_archive_request(self):
        """Test case for list_archive_request

        List ArchiveRequest objects  # noqa: E501
        """
        pass

    def test_list_archive_request1(self):
        """Test case for list_archive_request1

        List ArchiveRequest objects  # noqa: E501
        """
        pass

    def test_list_event_policy(self):
        """Test case for list_event_policy

        List EventPolicy objects  # noqa: E501
        """
        pass

    def test_list_event_policy1(self):
        """Test case for list_event_policy1

        List EventPolicy objects  # noqa: E501
        """
        pass

    def test_list_flow_export_policy(self):
        """Test case for list_flow_export_policy

        List FlowExportPolicy objects  # noqa: E501
        """
        pass

    def test_list_flow_export_policy1(self):
        """Test case for list_flow_export_policy1

        List FlowExportPolicy objects  # noqa: E501
        """
        pass

    def test_list_fwlog_policy(self):
        """Test case for list_fwlog_policy

        List FwlogPolicy objects  # noqa: E501
        """
        pass

    def test_list_fwlog_policy1(self):
        """Test case for list_fwlog_policy1

        List FwlogPolicy objects  # noqa: E501
        """
        pass

    def test_list_mirror_session(self):
        """Test case for list_mirror_session

        List MirrorSession objects  # noqa: E501
        """
        pass

    def test_list_mirror_session1(self):
        """Test case for list_mirror_session1

        List MirrorSession objects  # noqa: E501
        """
        pass

    def test_list_stats_alert_policy(self):
        """Test case for list_stats_alert_policy

        List StatsAlertPolicy objects  # noqa: E501
        """
        pass

    def test_list_stats_alert_policy1(self):
        """Test case for list_stats_alert_policy1

        List StatsAlertPolicy objects  # noqa: E501
        """
        pass

    def test_list_tech_support_request(self):
        """Test case for list_tech_support_request

        List TechSupportRequest objects  # noqa: E501
        """
        pass

    def test_list_troubleshooting_session(self):
        """Test case for list_troubleshooting_session

        List TroubleshootingSession objects  # noqa: E501
        """
        pass

    def test_list_troubleshooting_session1(self):
        """Test case for list_troubleshooting_session1

        List TroubleshootingSession objects  # noqa: E501
        """
        pass

    def test_update_alert(self):
        """Test case for update_alert

        Update Alert object  # noqa: E501
        """
        pass

    def test_update_alert1(self):
        """Test case for update_alert1

        Update Alert object  # noqa: E501
        """
        pass

    def test_update_alert_destination(self):
        """Test case for update_alert_destination

        Update AlertDestination object  # noqa: E501
        """
        pass

    def test_update_alert_destination1(self):
        """Test case for update_alert_destination1

        Update AlertDestination object  # noqa: E501
        """
        pass

    def test_update_alert_policy(self):
        """Test case for update_alert_policy

        Update AlertPolicy object  # noqa: E501
        """
        pass

    def test_update_alert_policy1(self):
        """Test case for update_alert_policy1

        Update AlertPolicy object  # noqa: E501
        """
        pass

    def test_update_audit_policy(self):
        """Test case for update_audit_policy

        Update AuditPolicy object  # noqa: E501
        """
        pass

    def test_update_audit_policy1(self):
        """Test case for update_audit_policy1

        Update AuditPolicy object  # noqa: E501
        """
        pass

    def test_update_event_policy(self):
        """Test case for update_event_policy

        Update EventPolicy object  # noqa: E501
        """
        pass

    def test_update_event_policy1(self):
        """Test case for update_event_policy1

        Update EventPolicy object  # noqa: E501
        """
        pass

    def test_update_flow_export_policy(self):
        """Test case for update_flow_export_policy

        Update FlowExportPolicy object  # noqa: E501
        """
        pass

    def test_update_flow_export_policy1(self):
        """Test case for update_flow_export_policy1

        Update FlowExportPolicy object  # noqa: E501
        """
        pass

    def test_update_fwlog_policy(self):
        """Test case for update_fwlog_policy

        Update FwlogPolicy object  # noqa: E501
        """
        pass

    def test_update_fwlog_policy1(self):
        """Test case for update_fwlog_policy1

        Update FwlogPolicy object  # noqa: E501
        """
        pass

    def test_update_mirror_session(self):
        """Test case for update_mirror_session

        Update MirrorSession object  # noqa: E501
        """
        pass

    def test_update_mirror_session1(self):
        """Test case for update_mirror_session1

        Update MirrorSession object  # noqa: E501
        """
        pass

    def test_update_stats_alert_policy(self):
        """Test case for update_stats_alert_policy

        Update StatsAlertPolicy object  # noqa: E501
        """
        pass

    def test_update_stats_alert_policy1(self):
        """Test case for update_stats_alert_policy1

        Update StatsAlertPolicy object  # noqa: E501
        """
        pass

    def test_update_troubleshooting_session(self):
        """Test case for update_troubleshooting_session

        Update TroubleshootingSession object  # noqa: E501
        """
        pass

    def test_update_troubleshooting_session1(self):
        """Test case for update_troubleshooting_session1

        Update TroubleshootingSession object  # noqa: E501
        """
        pass

    def test_watch_alert(self):
        """Test case for watch_alert

        Watch Alert objects. Supports WebSockets or HTTP long poll  # noqa: E501
        """
        pass

    def test_watch_alert1(self):
        """Test case for watch_alert1

        Watch Alert objects. Supports WebSockets or HTTP long poll  # noqa: E501
        """
        pass

    def test_watch_alert_destination(self):
        """Test case for watch_alert_destination

        Watch AlertDestination objects. Supports WebSockets or HTTP long poll  # noqa: E501
        """
        pass

    def test_watch_alert_destination1(self):
        """Test case for watch_alert_destination1

        Watch AlertDestination objects. Supports WebSockets or HTTP long poll  # noqa: E501
        """
        pass

    def test_watch_alert_policy(self):
        """Test case for watch_alert_policy

        Watch AlertPolicy objects. Supports WebSockets or HTTP long poll  # noqa: E501
        """
        pass

    def test_watch_alert_policy1(self):
        """Test case for watch_alert_policy1

        Watch AlertPolicy objects. Supports WebSockets or HTTP long poll  # noqa: E501
        """
        pass

    def test_watch_archive_request(self):
        """Test case for watch_archive_request

        Watch ArchiveRequest objects. Supports WebSockets or HTTP long poll  # noqa: E501
        """
        pass

    def test_watch_archive_request1(self):
        """Test case for watch_archive_request1

        Watch ArchiveRequest objects. Supports WebSockets or HTTP long poll  # noqa: E501
        """
        pass

    def test_watch_audit_policy(self):
        """Test case for watch_audit_policy

        Watch AuditPolicy objects. Supports WebSockets or HTTP long poll  # noqa: E501
        """
        pass

    def test_watch_audit_policy1(self):
        """Test case for watch_audit_policy1

        Watch AuditPolicy objects. Supports WebSockets or HTTP long poll  # noqa: E501
        """
        pass

    def test_watch_event_policy(self):
        """Test case for watch_event_policy

        Watch EventPolicy objects. Supports WebSockets or HTTP long poll  # noqa: E501
        """
        pass

    def test_watch_event_policy1(self):
        """Test case for watch_event_policy1

        Watch EventPolicy objects. Supports WebSockets or HTTP long poll  # noqa: E501
        """
        pass

    def test_watch_flow_export_policy(self):
        """Test case for watch_flow_export_policy

        Watch FlowExportPolicy objects. Supports WebSockets or HTTP long poll  # noqa: E501
        """
        pass

    def test_watch_flow_export_policy1(self):
        """Test case for watch_flow_export_policy1

        Watch FlowExportPolicy objects. Supports WebSockets or HTTP long poll  # noqa: E501
        """
        pass

    def test_watch_fwlog_policy(self):
        """Test case for watch_fwlog_policy

        Watch FwlogPolicy objects. Supports WebSockets or HTTP long poll  # noqa: E501
        """
        pass

    def test_watch_fwlog_policy1(self):
        """Test case for watch_fwlog_policy1

        Watch FwlogPolicy objects. Supports WebSockets or HTTP long poll  # noqa: E501
        """
        pass

    def test_watch_mirror_session(self):
        """Test case for watch_mirror_session

        Watch MirrorSession objects. Supports WebSockets or HTTP long poll  # noqa: E501
        """
        pass

    def test_watch_mirror_session1(self):
        """Test case for watch_mirror_session1

        Watch MirrorSession objects. Supports WebSockets or HTTP long poll  # noqa: E501
        """
        pass

    def test_watch_stats_alert_policy(self):
        """Test case for watch_stats_alert_policy

        Watch StatsAlertPolicy objects. Supports WebSockets or HTTP long poll  # noqa: E501
        """
        pass

    def test_watch_stats_alert_policy1(self):
        """Test case for watch_stats_alert_policy1

        Watch StatsAlertPolicy objects. Supports WebSockets or HTTP long poll  # noqa: E501
        """
        pass

    def test_watch_tech_support_request(self):
        """Test case for watch_tech_support_request

        Watch TechSupportRequest objects. Supports WebSockets or HTTP long poll  # noqa: E501
        """
        pass


if __name__ == '__main__':
    unittest.main()
