"""
    Cluster API reference

    Service name    # noqa: E501

    The version of the OpenAPI document: 1.0.0
    Generated by: https://openapi-generator.tech
"""


import sys
import unittest

import psm
from pensando_dss.psm.model.cluster_host import ClusterHost
globals()['ClusterHost'] = ClusterHost
from pensando_dss.psm.psm.model.cluster_auto_msg_host_watch_helper_watch_event import ClusterAutoMsgHostWatchHelperWatchEvent


class TestClusterAutoMsgHostWatchHelperWatchEvent(unittest.TestCase):
    """ClusterAutoMsgHostWatchHelperWatchEvent unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def testClusterAutoMsgHostWatchHelperWatchEvent(self):
        """Test ClusterAutoMsgHostWatchHelperWatchEvent"""
        # FIXME: construct object with mandatory attributes with example values
        # model = ClusterAutoMsgHostWatchHelperWatchEvent()  # noqa: E501
        pass


if __name__ == '__main__':
    unittest.main()
