"""
    Routing API reference

       # noqa: E501

    The version of the OpenAPI document: 1.0.0
    Generated by: https://openapi-generator.tech
"""


import sys
import unittest

import psm
from pensando_dss.psm.model.evpn_route_evpn_type2_route import EVPNRouteEVPNType2Route
from pensando_dss.psm.model.evpn_route_evpn_type5_route import EVPNRouteEVPNType5Route
globals()['EVPNRouteEVPNType2Route'] = EVPNRouteEVPNType2Route
globals()['EVPNRouteEVPNType5Route'] = EVPNRouteEVPNType5Route
from pensando_dss.psm.psm.model.routing_evpn_route import RoutingEVPNRoute


class TestRoutingEVPNRoute(unittest.TestCase):
    """RoutingEVPNRoute unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def testRoutingEVPNRoute(self):
        """Test RoutingEVPNRoute"""
        # FIXME: construct object with mandatory attributes with example values
        # model = RoutingEVPNRoute()  # noqa: E501
        pass


if __name__ == '__main__':
    unittest.main()
