"""
    Search API reference

    Service name    # noqa: E501

    The version of the OpenAPI document: 1.0.0
    Generated by: https://openapi-generator.tech
"""


import sys
import unittest

import psm
from pensando_dss.psm.model.search_search_query import SearchSearchQuery
globals()['SearchSearchQuery'] = SearchSearchQuery
from pensando_dss.psm.psm.model.search_search_request import SearchSearchRequest


class TestSearchSearchRequest(unittest.TestCase):
    """SearchSearchRequest unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def testSearchSearchRequest(self):
        """Test SearchSearchRequest"""
        # FIXME: construct object with mandatory attributes with example values
        # model = SearchSearchRequest()  # noqa: E501
        pass


if __name__ == '__main__':
    unittest.main()
