"""
    Security API reference

       # noqa: E501

    The version of the OpenAPI document: 1.0.0
    Generated by: https://openapi-generator.tech
"""


import sys
import unittest

import psm
from pensando_dss.psm.model.api_list_meta import ApiListMeta
from pensando_dss.psm.model.security_security_group import SecuritySecurityGroup
globals()['ApiListMeta'] = ApiListMeta
globals()['SecuritySecurityGroup'] = SecuritySecurityGroup
from pensando_dss.psm.psm.model.security_security_group_list import SecuritySecurityGroupList


class TestSecuritySecurityGroupList(unittest.TestCase):
    """SecuritySecurityGroupList unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def testSecuritySecurityGroupList(self):
        """Test SecuritySecurityGroupList"""
        # FIXME: construct object with mandatory attributes with example values
        # model = SecuritySecurityGroupList()  # noqa: E501
        pass


if __name__ == '__main__':
    unittest.main()
