"""
    Preferences API reference

    Service name    # noqa: E501

    The version of the OpenAPI document: 1.0.0
    Generated by: https://openapi-generator.tech
"""


import unittest

import psm
from pensando_dss.psm.api.preferences_v1_api import PreferencesV1Api  # noqa: E501


class TestPreferencesV1Api(unittest.TestCase):
    """PreferencesV1Api unit test stubs"""

    def setUp(self):
        self.api = PreferencesV1Api()  # noqa: E501

    def tearDown(self):
        pass

    def test_get_ui_global_settings(self):
        """Test case for get_ui_global_settings

        Get UIGlobalSettings object  # noqa: E501
        """
        pass

    def test_get_ui_global_settings1(self):
        """Test case for get_ui_global_settings1

        Get UIGlobalSettings object  # noqa: E501
        """
        pass

    def test_label_ui_global_settings(self):
        """Test case for label_ui_global_settings

        Label UIGlobalSettings object  # noqa: E501
        """
        pass

    def test_label_ui_global_settings1(self):
        """Test case for label_ui_global_settings1

        Label UIGlobalSettings object  # noqa: E501
        """
        pass

    def test_update_ui_global_settings(self):
        """Test case for update_ui_global_settings

        Update UIGlobalSettings object  # noqa: E501
        """
        pass

    def test_update_ui_global_settings1(self):
        """Test case for update_ui_global_settings1

        Update UIGlobalSettings object  # noqa: E501
        """
        pass

    def test_watch_ui_global_settings(self):
        """Test case for watch_ui_global_settings

        Watch UIGlobalSettings objects. Supports WebSockets or HTTP long poll  # noqa: E501
        """
        pass

    def test_watch_ui_global_settings1(self):
        """Test case for watch_ui_global_settings1

        Watch UIGlobalSettings objects. Supports WebSockets or HTTP long poll  # noqa: E501
        """
        pass


if __name__ == '__main__':
    unittest.main()
