"""
    Aggwatch API reference

       # noqa: E501

    The version of the OpenAPI document: v1
    Generated by: https://openapi-generator.tech
"""


import sys
import unittest

import psm
from pensando_dss.psm.psm.model.api_object_ref import ApiObjectRef


class TestApiObjectRef(unittest.TestCase):
    """ApiObjectRef unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def testApiObjectRef(self):
        """Test ApiObjectRef"""
        # FIXME: construct object with mandatory attributes with example values
        # model = ApiObjectRef()  # noqa: E501
        pass


if __name__ == '__main__':
    unittest.main()
