"""
    Cluster API reference

    Service name    # noqa: E501

    The version of the OpenAPI document: 1.0.0
    Generated by: https://openapi-generator.tech
"""


import sys
import unittest

import psm
from pensando_dss.psm.model.api_object_meta import ApiObjectMeta
from pensando_dss.psm.model.cluster_cluster_profile_spec import ClusterClusterProfileSpec
globals()['ApiObjectMeta'] = ApiObjectMeta
globals()['ClusterClusterProfileSpec'] = ClusterClusterProfileSpec
from pensando_dss.psm.psm.model.cluster_cluster_profile import ClusterClusterProfile


class TestClusterClusterProfile(unittest.TestCase):
    """ClusterClusterProfile unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def testClusterClusterProfile(self):
        """Test ClusterClusterProfile"""
        # FIXME: construct object with mandatory attributes with example values
        # model = ClusterClusterProfile()  # noqa: E501
        pass


if __name__ == '__main__':
    unittest.main()
