"""
    Objstore API reference

       # noqa: E501

    The version of the OpenAPI document: 1.0.0
    Generated by: https://openapi-generator.tech
"""


import sys
import unittest

import psm
from pensando_dss.psm.model.objstore_auto_msg_bucket_watch_helper_watch_event import ObjstoreAutoMsgBucketWatchHelperWatchEvent
globals()['ObjstoreAutoMsgBucketWatchHelperWatchEvent'] = ObjstoreAutoMsgBucketWatchHelperWatchEvent
from pensando_dss.psm.psm.model.objstore_auto_msg_bucket_watch_helper import ObjstoreAutoMsgBucketWatchHelper


class TestObjstoreAutoMsgBucketWatchHelper(unittest.TestCase):
    """ObjstoreAutoMsgBucketWatchHelper unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def testObjstoreAutoMsgBucketWatchHelper(self):
        """Test ObjstoreAutoMsgBucketWatchHelper"""
        # FIXME: construct object with mandatory attributes with example values
        # model = ObjstoreAutoMsgBucketWatchHelper()  # noqa: E501
        pass


if __name__ == '__main__':
    unittest.main()
