"""
    Monitoring API reference

    Service name    # noqa: E501

    The version of the OpenAPI document: 1.0.0
    Generated by: https://openapi-generator.tech
"""


import sys
import unittest

import psm
from pensando_dss.psm.model.api_object_meta import ApiObjectMeta
from pensando_dss.psm.model.monitoring_alert_policy_spec import MonitoringAlertPolicySpec
from pensando_dss.psm.model.monitoring_alert_policy_status import MonitoringAlertPolicyStatus
globals()['ApiObjectMeta'] = ApiObjectMeta
globals()['MonitoringAlertPolicySpec'] = MonitoringAlertPolicySpec
globals()['MonitoringAlertPolicyStatus'] = MonitoringAlertPolicyStatus
from pensando_dss.psm.psm.model.monitoring_alert_policy import MonitoringAlertPolicy


class TestMonitoringAlertPolicy(unittest.TestCase):
    """MonitoringAlertPolicy unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def testMonitoringAlertPolicy(self):
        """Test MonitoringAlertPolicy"""
        # FIXME: construct object with mandatory attributes with example values
        # model = MonitoringAlertPolicy()  # noqa: E501
        pass


if __name__ == '__main__':
    unittest.main()
