"""
    Sysruntime API reference

    Service name    # noqa: E501

    The version of the OpenAPI document: 1.0.0
    Generated by: https://openapi-generator.tech
"""


import sys
import unittest

import psm
from pensando_dss.psm.model.api_list_meta import ApiListMeta
from pensando_dss.psm.model.sysruntime_hw_connection_get_response import SysruntimeHWConnectionGetResponse
globals()['ApiListMeta'] = ApiListMeta
globals()['SysruntimeHWConnectionGetResponse'] = SysruntimeHWConnectionGetResponse
from pensando_dss.psm.psm.model.sysruntime_connection_status import SysruntimeConnectionStatus


class TestSysruntimeConnectionStatus(unittest.TestCase):
    """SysruntimeConnectionStatus unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def testSysruntimeConnectionStatus(self):
        """Test SysruntimeConnectionStatus"""
        # FIXME: construct object with mandatory attributes with example values
        # model = SysruntimeConnectionStatus()  # noqa: E501
        pass


if __name__ == '__main__':
    unittest.main()
