"""
    Security API reference

       # noqa: E501

    The version of the OpenAPI document: 1.0.0
    Generated by: https://openapi-generator.tech
"""


import sys
import unittest

import psm
from pensando_dss.psm.model.security_security_group import SecuritySecurityGroup
globals()['SecuritySecurityGroup'] = SecuritySecurityGroup
from pensando_dss.psm.psm.model.security_auto_msg_security_group_watch_helper_watch_event import SecurityAutoMsgSecurityGroupWatchHelperWatchEvent


class TestSecurityAutoMsgSecurityGroupWatchHelperWatchEvent(unittest.TestCase):
    """SecurityAutoMsgSecurityGroupWatchHelperWatchEvent unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def testSecurityAutoMsgSecurityGroupWatchHelperWatchEvent(self):
        """Test SecurityAutoMsgSecurityGroupWatchHelperWatchEvent"""
        # FIXME: construct object with mandatory attributes with example values
        # model = SecurityAutoMsgSecurityGroupWatchHelperWatchEvent()  # noqa: E501
        pass


if __name__ == '__main__':
    unittest.main()
