"""
    Network API reference

       # noqa: E501

    The version of the OpenAPI document: 1.0.0
    Generated by: https://openapi-generator.tech
"""


import sys
import unittest

import psm
from pensando_dss.psm.model.network_ipam_pool_info import NetworkIPAMPoolInfo
globals()['NetworkIPAMPoolInfo'] = NetworkIPAMPoolInfo
from pensando_dss.psm.psm.model.network_ipam_config import NetworkIPAMConfig


class TestNetworkIPAMConfig(unittest.TestCase):
    """NetworkIPAMConfig unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def testNetworkIPAMConfig(self):
        """Test NetworkIPAMConfig"""
        # FIXME: construct object with mandatory attributes with example values
        # model = NetworkIPAMConfig()  # noqa: E501
        pass


if __name__ == '__main__':
    unittest.main()
